fan_offset

Function fan_offset 

pub fn fan_offset(along: f32, across: f32, umbra: f32, radius: f32) -> f32
The length of the offset Skia’s corner fan interpolates at along and across, a point’s distances out from the umbra’s corner toward the two edges, for an umbra inset umbra and a corner radius radius: 0 at the umbra and 1 on the outer edge. The fan’s triangles meet the edge at the umbra line, at umbra - radius along it and at the corner, whose offsets Skia skews when the umbra is deeper than the radius.