layer_transform_to_window

Function layer_transform_to_window 

pub fn layer_transform_to_window(
    parent: ProjectiveTransform,
    origin: Point,
    bounds: Rect,
    layer: &GraphicsLayer,
) -> ProjectiveTransform
Extends an ancestor mapping from untransformed layout coordinates to window coordinates with this node’s graphics layer. origin and bounds describe the node before any ancestor transforms; bounds is relative to origin.