Module scene_builder

Module scene_builder 

Structs

GraphUpdateReport

Enums

GraphRebuildReason
Why a scoped scene update could not be applied, forcing the caller to throw the render graph away and build it again from the applier.
GraphUpdate

Functions

build_graph_from_applier
build_graph_from_layout_tree
expand_text_bounds_for_baseline_shift
rebuild_graph_from_applier
Builds root’s graph again, its layers taking the allocations of previous, the graph it replaces.
update_graph_from_applier
update_graph_from_applier_report