pub struct Scene {
pub graph: Option<RenderGraph>,
pub hits: Vec<HitRegion>,
pub next_hit_z: usize,
pub node_index: HashMap<NodeId, usize>,
/* private fields */
}Fields
graph: Option<RenderGraph>hits: Vec<HitRegion>next_hit_z: usizenode_index: HashMap<NodeId, usize>Implementations
Sourceimpl Scene
impl Scene
pub fn new() -> Self
pub fn diagnostics(&self) -> &RenderDiagnostics
Sourcepub fn push_hit(
&mut self,
node_id: NodeId,
capture_path: &[NodeId],
geometry: HitGeometry<'_>,
shape: Option<RoundedCornerShape>,
click_actions: impl IntoIterator<Item = ClickAction>,
pointer_inputs: &[Rc<dyn Fn(PointerEvent)>],
)
pub fn push_hit( &mut self, node_id: NodeId, capture_path: &[NodeId], geometry: HitGeometry<'_>, shape: Option<RoundedCornerShape>, click_actions: impl IntoIterator<Item = ClickAction>, pointer_inputs: &[Rc<dyn Fn(PointerEvent)>], )
Adds an interactive target in draw order, ignoring targets without handlers.
Sourcepub fn clear_hits(&mut self)
pub fn clear_hits(&mut self)
Removes all hit targets and releases their handlers while retaining vector capacity.
pub fn replace_graph(&mut self, graph: RenderGraph)