pub struct ShadowLight {
pub x: f32,
pub y: f32,
pub z: f32,
pub radius: f32,
pub pixels_per_unit: f32,
}Expand description
The light elevation shadows are cast by, in the units and coordinates the shadow is collected in.
Fields
x: f32y: f32z: f32radius: f32pixels_per_unit: f32Device pixels per unit: Skia scales the ambient penumbra by the caster’s height in pixels.
Implementations
Sourceimpl ShadowLight
impl ShadowLight
Sourcepub fn for_window(
width: f32,
height: f32,
units_per_dp: f32,
pixels_per_unit: f32,
) -> Self
pub fn for_window( width: f32, height: f32, units_per_dp: f32, pixels_per_unit: f32, ) -> Self
The light over a window width × height units in size whose origin
is the collection origin, where one dp is units_per_dp units. Matches
Kotlin: ThreadedRenderer.setLightCenter on Android and its copy in
Compose Multiplatform’s GraphicsLayerOwnerLayer.skiko.kt.