pub struct ShapeDrawParams {
pub rect: Rect,
pub local_rect: Rect,
pub quad: [[f32; 2]; 4],
pub brush: Brush,
pub shape: Option<RoundedCornerShape>,
pub stroke: Option<Stroke>,
pub arc: Option<ArcGeometry>,
pub clip: Option<Rect>,
pub blend_mode: BlendMode,
pub motion_context_animated: bool,
}Fields
rect: Rectlocal_rect: Rectquad: [[f32; 2]; 4]brush: Brushshape: Option<RoundedCornerShape>stroke: Option<Stroke>Some means “stroke the outline of local_rect/shape” instead of
filling it. The width is already in local_rect units (the layer scale
has been applied), and local_rect/quad have already been inflated by
half that width so the outer half of the stroke has geometry to land on.
arc: Option<ArcGeometry>Some replaces the rect geometry entirely with a circular band. The
center and radii are in local_rect units.
clip: Option<Rect>blend_mode: BlendModemotion_context_animated: boolAuto Trait Implementations
impl Freeze for ShapeDrawParams
impl RefUnwindSafe for ShapeDrawParams
impl Send for ShapeDrawParams
impl Sync for ShapeDrawParams
impl Unpin for ShapeDrawParams
impl UnsafeUnpin for ShapeDrawParams
impl UnwindSafe for ShapeDrawParams